@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+from decimal import Decimal
 from pagador.acesso.externo import Conexao
 from pagador.pedido import notificador
 from pagador.envio.models import Pedido
@@ -34,7 +35,10 @@ class Enviar(object):
     #FIXME: rever isso ao refatorar o sistema de pedido
     @property
     def valor_envio(self):
-        return self.pedido.valor_total - self.pedido.valor_subtotal + self.pedido.valor_desconto
+        valor_total = self.pedido.valor_total or Decimal("0.00")
+        valor_subtotal = self.pedido.valor_subtotal or Decimal("0.00")
+        valor_desconto = self.pedido.valor_desconto or Decimal("0.00")
+        return valor_total - valor_subtotal + valor_desconto
 
 
 class EnviarPedido(Plugavel):
