@@ -148,7 +148,7 @@ class RegistrarPagamento(Plugavel):
     def obtem_dados_do_gateway(self):
         resultado = self.request()
         if resultado.get("reenviar", False):
-            resultado = self.get(segunda_tentativa=True)
+            resultado = self.request(segunda_tentativa=True)
         if resultado["status"] == 200:
             return resultado["content"]
         return {}
